## 介绍
测试python环境！

借助zyh这个库

github repo: 

[https://github.com/amanyara/zyh](https://github.com/amanyara/zyh)

## 安装
你可以使用
```
pip install zyh
```
来下载。（推荐，因为还会在你系统内安装同名的命令行工具）


或者直接clone这个repo

## 用法
在当前文件夹下



假如你使用pip的方式安装，只需要运行
```
zyh
```
即可

